Struct ClearAutocmdsOptsBuilder
pub struct ClearAutocmdsOptsBuilder(ClearAutocmdsOpts);Tuple Fields
0: ClearAutocmdsOptsImplementations
impl ClearAutocmdsOptsBuilder
impl ClearAutocmdsOptsBuilder
pub fn buffer(&mut self, buffer: Buffer) -> &mut ClearAutocmdsOptsBuilder
pub fn buffer(&mut self, buffer: Buffer) -> &mut ClearAutocmdsOptsBuilder
Only clear the autocommands local to a specific Buffer. Cannot be
pub fn events<'a, I>(&mut self, events: I) -> &mut ClearAutocmdsOptsBuilderwhere
I: IntoIterator<Item = &'a str>,
pub fn events<'a, I>(&mut self, events: I) -> &mut ClearAutocmdsOptsBuilderwhere
I: IntoIterator<Item = &'a str>,
Clear all the autocommands triggered by one or more of the specified
pub fn group<G>(&mut self, group: G) -> &mut ClearAutocmdsOptsBuilderwhere
G: StringOrInt,
pub fn group<G>(&mut self, group: G) -> &mut ClearAutocmdsOptsBuilderwhere
G: StringOrInt,
Only clear the autocommands matching specific patterns. For example, if
pub fn patterns<'a, I>(&mut self, patterns: I) -> &mut ClearAutocmdsOptsBuilderwhere
I: IntoIterator<Item = &'a str>,
pub fn patterns<'a, I>(&mut self, patterns: I) -> &mut ClearAutocmdsOptsBuilderwhere
I: IntoIterator<Item = &'a str>,
Only clear the autocommands belonging to a specific augroup. The
pub fn build(&mut self) -> ClearAutocmdsOpts