Struct EchoOptsBuilder
pub struct EchoOptsBuilder(EchoOpts);Tuple Fields
0: EchoOptsImplementations
impl EchoOptsBuilder
impl EchoOptsBuilder
pub fn data(&mut self, data: Dictionary) -> &mut EchoOptsBuilder
pub fn data(&mut self, data: Dictionary) -> &mut EchoOptsBuilder
Dictionary containing additional information.
pub fn err(&mut self, err: bool) -> &mut EchoOptsBuilder
pub fn err(&mut self, err: bool) -> &mut EchoOptsBuilder
Treat the message like :echoerr.
pub fn id<Id>(&mut self, id: Id) -> &mut EchoOptsBuilderwhere
Id: StringOrInt,
pub fn id<Id>(&mut self, id: Id) -> &mut EchoOptsBuilderwhere
Id: StringOrInt,
Message id for updating existing message.
pub fn kind<S>(&mut self, kind: S) -> &mut EchoOptsBuilderwhere
S: Into<String>,
pub fn kind<S>(&mut self, kind: S) -> &mut EchoOptsBuilderwhere
S: Into<String>,
Set the ui-messages kind with which this message will be emitted.
pub fn percent(&mut self, percent: u8) -> &mut EchoOptsBuilder
pub fn percent(&mut self, percent: u8) -> &mut EchoOptsBuilder
How much progress is done on the progress message.
pub fn status(&mut self, status: ProgressMessageStatus) -> &mut EchoOptsBuilder
pub fn status(&mut self, status: ProgressMessageStatus) -> &mut EchoOptsBuilder
The current status of the progress message.
pub fn title<S>(&mut self, title: S) -> &mut EchoOptsBuilderwhere
S: Into<String>,
pub fn title<S>(&mut self, title: S) -> &mut EchoOptsBuilderwhere
S: Into<String>,
The title of the progress message.
pub fn verbose(&mut self, verbose: bool) -> &mut EchoOptsBuilder
pub fn verbose(&mut self, verbose: bool) -> &mut EchoOptsBuilder
Message is controlled by the verbose option. Nvim invoked with
pub fn build(&mut self) -> EchoOpts